@@ -13,45 +13,45 @@ CWH = 2
 
 # ---------------
 
-def min_wh2min_max(bbox: torch.Tensor) -> torch.Tensor:
+def _min_wh2min_max(bbox: torch.Tensor) -> torch.Tensor:
     bbox[..., 2] += bbox[..., 0]
     bbox[..., 3] += bbox[..., 1]
     return bbox
 
 
-def min_wh2cwh(bbox: torch.Tensor) -> torch.Tensor:
+def _min_wh2cwh(bbox: torch.Tensor) -> torch.Tensor:
     bbox[..., 0] += bbox[..., 2] / 2
     bbox[..., 1] += bbox[..., 3] / 2
     return bbox
 
 
-def cwh2min_wh(bbox: torch.Tensor) -> torch.Tensor:
+def _cwh2min_wh(bbox: torch.Tensor) -> torch.Tensor:
     bbox[..., 0] -= bbox[..., 2] / 2
     bbox[..., 1] -= bbox[..., 3] / 2
     return bbox
 
 
-def cwh2min_max(bbox: torch.Tensor) -> torch.Tensor:
-    return min_wh2min_max(cwh2min_wh(bbox))
+def _cwh2min_max(bbox: torch.Tensor) -> torch.Tensor:
+    return _min_wh2min_max(_cwh2min_wh(bbox))
 
 
-def min_max2min_wh(bbox: torch.Tensor) -> torch.Tensor:
+def _min_max2min_wh(bbox: torch.Tensor) -> torch.Tensor:
     bbox[..., 2] -= bbox[..., 0]
     bbox[..., 3] -= bbox[..., 1]
     return bbox
 
 
-def min_max2cwh(bbox: torch.Tensor) -> torch.Tensor:
-    return min_wh2cwh(min_max2min_wh(bbox))
+def _min_max2cwh(bbox: torch.Tensor) -> torch.Tensor:
+    return _min_wh2cwh(_min_max2min_wh(bbox))
 
 
 _methods = [[lambda x: x] * 3 for _ in range(3)]
-_methods[MIN_WH][MIN_MAX] = min_wh2min_max
-_methods[MIN_WH][CWH] = min_wh2cwh
-_methods[CWH][MIN_WH] = cwh2min_wh
-_methods[CWH][MIN_MAX] = cwh2min_max
-_methods[MIN_MAX][CWH] = min_max2cwh
-_methods[MIN_MAX][MIN_WH] = min_max2min_wh
+_methods[MIN_WH][MIN_MAX] = _min_wh2min_max
+_methods[MIN_WH][CWH] = _min_wh2cwh
+_methods[CWH][MIN_WH] = _cwh2min_wh
+_methods[CWH][MIN_MAX] = _cwh2min_max
+_methods[MIN_MAX][CWH] = _min_max2cwh
+_methods[MIN_MAX][MIN_WH] = _min_max2min_wh
 
 
 def transform(
@@ -60,7 +60,8 @@ def transform(
         tar_fmt: BboxFmt,
         inplace: bool = False) -> torch.Tensor:
     """
-    X_MIN_Y_MIN_WH to X_MIN_Y_MIN_X_MAX_Y_MAX
+    Transform bound box's format.
+    x corresponds to width, y corresponds to height.
     Args:
         bbox: bound box
         bbox_fmt: format of bbox
@@ -110,23 +111,24 @@ def calc_iou(box1: torch.Tensor, box2: torch.Tensor, fmt1: int, fmt2: int) -> to
     return iou
 
 
-def encode_points(pts: torch.Tensor,
+def encode_bboxes(bboxes: torch.Tensor,
                   raw_img_size: Tuple[int, int],
                   transformed_img_size: Tuple[int, int]) -> torch.Tensor:
     """
 
     Args:
-        pts: points with format (x_min, y_min, w, h)
+        bboxes: bound boxes[..., 4]
         raw_img_size:
         transformed_img_size:
 
     Returns:
         resized bound box
     """
-    pts = pts.clone()
+    assert bboxes.size(-1) == 4
+    bboxes = bboxes.clone()
     wr, hr = transformed_img_size[0] / raw_img_size[0], transformed_img_size[1] / raw_img_size[1]
-    pts[..., 0] *= wr
-    pts[..., 2] *= wr
-    pts[..., 1] *= hr
-    pts[..., 3] *= hr
-    return pts
+    bboxes[..., 0] *= wr
+    bboxes[..., 2] *= wr
+    bboxes[..., 1] *= hr
+    bboxes[..., 3] *= hr
+    return bboxes
